Index: src/interpreter/interpreter.cc |
diff --git a/src/interpreter/interpreter.cc b/src/interpreter/interpreter.cc |
index c87d70ae6b2047eaca3861a7868c2330b7f4691e..16fadc834bf81ec6845c19eb80b0548cb8a37e4c 100644 |
--- a/src/interpreter/interpreter.cc |
+++ b/src/interpreter/interpreter.cc |
@@ -2024,17 +2024,20 @@ void Interpreter::DoCreateFunctionContext(InterpreterAssembler* assembler) { |
__ Dispatch(); |
} |
-// CreateWithContext <register> |
+// CreateWithContext <register> <scope_info_idx> |
// |
// Creates a new context for a with-statement with the object in |register| and |
// the closure in the accumulator. |
void Interpreter::DoCreateWithContext(InterpreterAssembler* assembler) { |
Node* reg_index = __ BytecodeOperandReg(0); |
Node* object = __ LoadRegister(reg_index); |
+ Node* scope_info_idx = __ BytecodeOperandIdx(1); |
+ Node* scope_info = __ LoadConstantPoolEntry(scope_info_idx); |
Node* closure = __ GetAccumulator(); |
Node* context = __ GetContext(); |
- __ SetAccumulator( |
- __ CallRuntime(Runtime::kPushWithContext, context, object, closure)); |
+ __ SetAccumulator(__ CallRuntime(Runtime::kPushWithContext, context, object, |
+ scope_info, closure)); |
__ Dispatch(); |
} |
@@ -2024,17 +2024,20 @@ void Interpreter::DoCreateFunctionContext(InterpreterAssembler* assembler) { |
// |
-// Creates a new context for a with-statement with the object in |register| and |
-// the closure in the accumulator. |
+// Creates a new context with the ScopeInfo at |scope_info_idx| for a |
+// with-statement with the object in |register| and the closure in the |
+// accumulator. |
void Interpreter::DoCreateWithContext(InterpreterAssembler* assembler) { |
Node* reg_index = __ BytecodeOperandReg(0); |